@@ -50,20 +50,18 @@ class Manager(object):
 
         raise gen.Return(items)
 
-    @gen.coroutine
-    def count(self, query=None):
+    def count(self, query=None, callback=None):
         client = Client(Database(), self.collection.__collection__)
-        count = yield client.find(query).count()
-        raise gen.Return(count)
+        client.find(query).count(callback=callback)
 
     @gen.engine
     def distinct(self, key, callback, query=None):
         client = Client(Database(), self.collection.__collection__)
         client.find(query).distinct(key, callback=callback)
 
-    @gen.coroutine
+    @gen.engine
     def geo_near(self, near, max_distance=None, num=None, spherical=None,
-        unique_docs=None, query=None, **kw):
+        unique_docs=None, query=None, callback=None, **kw):
 
         command = SON({"geoNear": self.collection.__collection__})
 
@@ -92,7 +90,7 @@ class Manager(object):
             for item in result['results']:
                 items.append(self.collection.create(item['obj'], cleaned=True))
 
-        raise gen.Return(items)
+        callback(items)
 
     @gen.engine
     def map_reduce(self, map_, reduce_, callback, query=None, out=None):
